@@ -20,10 +20,12 @@ from .builtins import (
     next,
     set,
     sum,
+    tuple,
     zip,
 )
 from .itertools import (
     accumulate,
+    batched,
     chain,
     combinations,
     combinations_with_replacement,
